<?php
require_once("cwfUI.inc.php");

class DbAdminGroupUI extends cwfUI {
  protected static $accessRight = "edit_groups";
  protected static $dataClass = "DbAdminGroup";
  
  public function __construct() {
    parent::__construct();
    $this->initialize();
  }
  
  protected function initialize() {
    parent::initialize();
    $this->title = _("Admin Groups");
  }
  
  static public function getValidationRules() {
    $rules = array(
        "db_admin_group_name"=>array("required"=>true)
      );
    $messages = array(
        "db_admin_group_name"=>_("Please enter a group name.")
      );
    
    $validationRules = new FormValidation($rules, $messages);
    return $validationRules;
  }

  public function getPostBackXML(DbConnection $DB, $action) {
    $xml = "";
    switch ($action) {
      case "updateForm":
        $xml .= parent::getPostBackXML($DB, $action);
        $xml .= "  <replaceHTMLElement id=\"span#group_members\">\n";
        $xml .= "    <![CDATA[".$this->getMemberListHTML($DB)."]]>\n";
        $xml .= "  </replaceHTMLElement>\n";
        break;
      case "save":
        $xml .= parent::getPostBackXML($DB, $action);
        break;
      case "saveasnew":
      case "delete":
        $xml .= parent::getPostBackXML($DB, $action);
        $xml .= "  <replaceHTMLElement id=\"span#group_members\">\n";
        $xml .= "    <![CDATA[".$this->getMemberListHTML($DB)."]]>\n";
        $xml .= "  </replaceHTMLElement>\n";
        break;
    }
    return $xml;
  }
  
  private function getMemberListHTML(DbConnection $DB) {
    return "<span class=\"textarea\" id=\"group_members\" name=\"group_members\">".
           implode("<br>\n", array_map(function($value){ return $value['name']; }, 
                                       DbAdmin::readList($DB, "db_admin_group_ids REGEXP '(^|,){$this->data->id}(,|$)'"))).
           "</span>";
  }
  
  public function getHTML(DbConnection $DB) {
?>
<form id="kdb_form" action="" method="post" enctype="multipart/form-data">
<p>
  <label for="group_list"><?= _("Administrator groups") ?>:</label>
  <select id="group_list" name="group_list" class="select_id" onChange="kdbUpdateForm(this, 'DbAdminGroupUI');" size="10">
    <option value="-1"><?= _("New group") ?></option>
<?php
    $groups = static::readList($DB);
    foreach ($groups as $group)
      echo "    <option value=\"{$group['id']}\">{$group['name']}</option>\n";
?>
  </select>
</p>

<input type="hidden" id="db_admin_group_id" name="db_admin_group_id" class="id" value="<?= $this->data->db_admin_group_id ?>">

<p>
  <label for="db_admin_group_name" class="required"><?=_("Group name")?>:</label>
  <input type="text" id="db_admin_group_name" name="db_admin_group_name" value="<?=$this->data->db_admin_group_name?>" class="required">
</p>

<p>
  <label for="group_members"><?=_("Members")?>:</label>
  <?=$this->getMemberListHTML($DB)?>
</p>

<div class="form_controls_bottom">
<p>
  <input class="indented" type="submit" id="kdb_save" name="kdb_save" value="<?=_("Save")?>" onClick="kdbSaveEntry('DbAdminGroupUI', 'save'); return false;">
  <input type="submit" id="kdb_save_as" name="kdb_save_as" value="<?=_("Save as new")?>" onClick="kdbSaveEntry('DbAdminGroupUI', 'saveasnew'); return false;">
  <input type="submit" id="kdb_delete" name="kdb_delete" value="<?=_("Delete")?>" onClick="kdbDeleteEntry('DbAdminGroupUI'); return false;">
</p>
</div>
</form>
<?php
  }
}

?>