<?php 
require_once("icwfData.inc.php");
require_once("FormValidation.inc.php");

class EmailTemplate implements icwfData {
  private static $noExport = array();
  private static $notInArray = array("validation");
  private $validation;
  
  private $email_template_id;
  private $email_template_name;
  private $email_subject;
  private $email_text;
  private $db_admin_id;
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // initialize
  private function initialize() {
    foreach ($this as $key => $value)
      $this->$key = null;
  }
  
  public function __construct(FormValidation $validation=null) {
    $this->initialize();
    
    $this->validation = $validation;
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // get values
  public function __get($name) {
    if($name == "id") $name = "email_template_id";
    if (array_key_exists($name, get_class_vars(get_class())) && !in_array($name, self::$noExport))
      return $this->$name;
      
    return null;
  }

  public function getIDName() {
    return "email_template_id";
  }
  
  public function toArray() {
    $array = array();
    foreach ($this as $key => $value)
      if(!in_array($key, self::$notInArray))
        $array[$key] = $value; 
    return $array;
  }
  
  public function getPostBackData() {
    return array($this->getIDName()=>$this->id);
  }
  
  ////////////////////////////////////////////////////////////////////////////////////////////////
  // set values
  public function setValidation(FormValidation $validation) {
    $this->validation = $validation;
  }
  
  public function fromArray($array) {
    
    foreach ($this as $key => $value) {
      switch ($key) {
        case "validation":
          break;
          
        case "email_template_id":
        case "db_admin_id":
          if(isset($array[$key]) && preg_match('~^[0-9]+$~', $array[$key]))
            $this->$key = $array[$key];
          else
            $this->$key = null;
          break;

        default:
          if(isset($array[$key]))
            $this->$key = $array[$key];
          else
            $this->$key = null;
          break;
      }
    }
    return $this->validation->validate($array);
  }

  /////////////////////////////////////////////////////////////////////////////////////////////////
  // database operations - read
  public function readData(DbConnection $DB, $conditions) {
    $whereConditions = array();
    foreach ($conditions as $key => $value)
      if(array_key_exists($key, get_class_vars(get_class())))
        $whereConditions[] = "$key=$value";
    
    $result = $DB->query("SELECT * FROM email_templates WHERE ".implode(" AND ", $whereConditions).";");
    
    if(!$DB->errno() && $DB->num_rows($result)>0) {
      $group = $DB->fetch_array($result);
      foreach ($group as $property => $value)
        if(property_exists($this, $property))
          $this->$property = $value;
      
      return array(0, "");
    }
    else
      return array($DB->errno(), $DB->error());
  }
  
  static public function readList(DbConnection $DB) {
    $result = $DB->query("SELECT email_template_id id, email_template_name name FROM email_templates WHERE db_admin_id='{$_SESSION['admin']['db_admin_id']}' ORDER BY email_template_name;");
    
    $list = array();
    while ($disclaimer = $DB->fetch_array($result))
      $list[] = $disclaimer;
      
    return $list;
  }

  /////////////////////////////////////////////////////////////////////////////////////////////////
  // database operations - write
  public function writeData(DbConnection $DB) {
    if(!isset($this->email_template_name) || !$this->email_template_name) return;
    if(isset($this->email_template_id) && $this->email_template_id) {
      $result = $DB->query("UPDATE email_templates SET
          email_template_name='{$this->email_template_name}',
          email_subject='{$this->email_subject}',
          email_text='{$this->email_text}',
          db_admin_id='{$_SESSION['admin']['db_admin_id']}'
          WHERE email_template_id='{$this->email_template_id}';");
      $logEntry = "Email template '{$this->email_template_id}' changed.";
    }
    else {
      $result = $DB->query("INSERT INTO email_templates(
          email_template_name,
          email_subject,
          email_text,
          db_admin_id
        ) VALUES(
          '{$this->email_template_name}',
          '{$this->email_subject}',
          '{$this->email_text}',
          '{$_SESSION['admin']['db_admin_id']}'
        );");
      
      $this->email_template_id = $DB->insert_id();
      $logEntry = "Email template '{$this->email_template_id}' created.";
    }
    if(!$DB->errno()) {
      KDbLog::writeLog($DB, $logEntry);
      return array(0, "");
    }
    else
      return array($DB->errno(), $DB->error());
  }

  static public function deleteData(DbConnection $DB, $id) {
    if(preg_match("~^[0-9]+$~", $id))
      $condition = "email_template_id='{$id}'";
    else
      $condition = $id;

    $result = $DB->query("DELETE FROM email_templates WHERE {$condition};");
    
    if(!$DB->errno() && $DB->affected_rows()>0) {
      KDbLog::writeLog($DB, "Email template(s) deleted ($condition).");
      return array(0, "");
    }
    else 
      return array($DB->errno(), $DB->error());
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // database operations - misc
  static public function createTable(DbConnection $DB) {
    $result = $DB->query("
      CREATE TABLE email_templates (
        email_template_id int unsigned NOT NULL AUTO_INCREMENT PRIMARY KEY,
        email_template_name text,
        email_subject text,
        email_text text,
        db_admin_id int unsigned NOT NULL,
        INDEX(db_admin_id)
      );");
    if ($result) { echo _("&nbsp;&nbsp;- creating table").": 'email_templates'.<br>\n"; }
    else { echo _("&nbsp;&nbsp;<b>- Error when creating table</b>")." 'email_templates'<br>\n"; $error = 1; }
  }
}
?>