<?php
class DbConnection {
  // Connect
  private $db_link;
  private $tables;
  private $table_indexes;
  private $table_dependencies;
  private $table_restore;
  private $connectionError;
  
  public function __construct($host, $user, $passwd, $db_name) {
    $this->db_link = new mysqli($host, $user, $passwd, $db_name);
    $this->db_link->set_charset("utf8");
    
    $this->tables = array();
    $this->table_indexes = array();
    $this->table_dependencies = array();
    $this->table_restore = array();

    if(!defined("DB_ASSOC")) define('DB_ASSOC', MYSQLI_ASSOC);
    if(!defined("DB_NUM")) define('DB_NUM', MYSQLI_NUM);
    if(!defined("DB_BOTH")) define('DB_BOTH', MYSQLI_BOTH);
    
    if($this->db_link->connect_errno) 
      $this->connectionError = _("<b>Database connection failed!</b><br>Please contact your admin.");
    else {
      if (!$this->result($this->db_link->query("SELECT DATABASE()"), 0, 0))
        $this->connectionError = _("<b>No database selected!</b><br>Please contact your admin.");
    }
  }
  
  public function setTableDependencies($tables, $indexes, $dependencies, $restore) {
    $this->tables = $tables;
    $this->table_indexes = $indexes;
    $this->table_dependencies = $dependencies;
    $this->table_restore = $restore;
  }
  
  public function getConnectionError() {
    return $this->connectionError;
  }
  
  // Query Statement
  public function query($query) {
    return $this->db_link->query($query);
  }
  public function multi_query($query) {
    $this->db_link->multi_query($query);
  
    while($this->db_link->more_results()) $this->db_link->next_result();
  
    return $this->db_link->store_result();
  }
  
  // fetch array statement
  public function fetch_array ($result, $result_type=DB_ASSOC) {
    return $result->fetch_array($result_type);
  }
  
  // fetch row statement
  public function fetch_row ($result) {
    return $result->fetch_row($result);
  }
  
  // result statement
  public function result ($result, $data_set_no, $field) {
    if(!$result instanceof mysqli_result) return null;
    $result->data_seek($data_set_no);
    $row = $result->fetch_row();
    
    return $row[$field];
  }
  
  // num rows statement
  public function num_rows ($result) {
    return $result->num_rows;
  }
  
  // affected rows statement
  public function affected_rows () {
    $affectedRows = $this->db_link->affected_rows; 
    if($affectedRows==0)
      $affectedRows = preg_replace("~^[^:]+:\s*([0-9]+).*$~", '$1', $this->info());
    return $affectedRows;
  }
  
  public function info() {
    return $this->db_link->info;
  }
  
  public function get_server_info() {
    return "MySQL: ".$this->db_link->server_info;
  }
  
  // insert_id statement
  public function insert_id () {
    return $this->db_link->insert_id;
  }
  
  // free_result statement
  public function free_result ($result) {
    return $this->db_link->free_result();
  }
  
  // data_seek statement
  public function data_seek ($result, $data_set_no) {
    return $result->data_seek($data_set_no);
  }
  
  // Error-Messages
  public function db_die() {
    echo $this->db_link->error;
    echo "</body></html>";
    exit;
  }
  public function errno() {
    return $this->db_link->errno;
  }
  public function error() {
    return $this->db_link->error;
  }
  public function error_list() {
    return $this->db_link->error_list;
  }
  
  public function write_log($admin_id, $log_entry) {
    $this->query("INSERT INTO log (log_date, db_admin_id, log_entry) VALUES (NOW(), '{$admin_id}', '{$log_entry}');");
  }
}
?>